======================
Writing your own class
======================

Eventually, you'll come across an Java API that requires you to provide
a class instance (usually one implementing an interface) as an argument.
For example, when using Java GUI classes, you often need to define "handler"
classes to describe how a GUI element will respond to mouse clicks and key
presses.

**TODO**

Next steps
==========

???
